Modul Documentation
===================

Constants
---------

.. autodata:: boozelib.PA
.. autodata:: boozelib.PB
.. autodata:: boozelib.W

Functions
---------

.. autofunction:: boozelib.get_blood_alcohol_content
.. autofunction:: boozelib.get_degradation
.. autofunction:: boozelib.calculate_alcohol
.. autofunction:: boozelib.calculate_degradation
.. autofunction:: boozelib.calculate_body_water
.. autofunction:: boozelib.gramm_to_promille
.. autofunction:: boozelib.promille_to_gramm
